# logbook
## Getting Started
### Requirements
Operation systems: Windows, Linux, Mac OS.

Python version: 3.7.1.

### Installation
Use pip to install the module:
```
pip install pypyrus_logbook
```

### How to Use
To start just call the logger:
```
import pypyrus_logbook as logbook


logger = logbook.logger()
```
